/**
 ******************************************************************************
 * @addtogroup UAVObjects OpenPilot UAVObjects
 * @{ 
 * @addtogroup MixerSettings MixerSettings
 * @brief Settings for the @ref ActuatorModule that controls the channel assignments for the mixer based on AircraftType
 *
 * Autogenerated files and functions for MixerSettings Object
 * @{ 
 *
 * @file       mixersettings.c
 * @author     The OpenPilot Team, http://www.openpilot.org Copyright (C) 2010.
 * @brief      Implementation of the MixerSettings object. This file has been 
 *             automatically generated by the UAVObjectGenerator.
 * 
 * @note       Object definition file: mixersettings.xml. 
 *             This is an automatically generated file.
 *             DO NOT modify manually.
 *
 * @see        The GNU Public License (GPL) Version 3
 *
 *****************************************************************************/
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "openpilot.h"
#include "mixersettings.h"

// Private variables
static UAVObjHandle handle;

// Private functions
static void setDefaults(UAVObjHandle obj, uint16_t instId);

/**
 * Initialize object.
 * \return 0 Success
 * \return -1 Failure
 */
int32_t MixerSettingsInitialize()
{
	// Register object with the object manager
	handle = UAVObjRegister(MIXERSETTINGS_OBJID, MIXERSETTINGS_NAME, MIXERSETTINGS_METANAME, 0,
			MIXERSETTINGS_ISSINGLEINST, MIXERSETTINGS_ISSETTINGS, MIXERSETTINGS_NUMBYTES, &setDefaults);

	// Done
	if (handle != 0)
	{
		return 0;
	}
	else
	{
		return -1;
	}
}

/**
 * Initialize object fields and metadata with the default values.
 * If a default value is not specified the object fields
 * will be initialized to zero.
 */
static void setDefaults(UAVObjHandle obj, uint16_t instId)
{
	MixerSettingsData data;
	UAVObjMetadata metadata;

	// Initialize object fields to their default values
	UAVObjGetInstanceData(obj, instId, &data);
	memset(&data, 0, sizeof(MixerSettingsData));
	data.MaxAccel = 1000;
	data.FeedForward = 0;
	data.AccelTime = 0;
	data.DecelTime = 0;
	data.ThrottleCurve1[0] = 0;
	data.ThrottleCurve1[1] = 0.25;
	data.ThrottleCurve1[2] = 0.5;
	data.ThrottleCurve1[3] = 0.75;
	data.ThrottleCurve1[4] = 1;
	data.ThrottleCurve2[0] = 0;
	data.ThrottleCurve2[1] = 0.25;
	data.ThrottleCurve2[2] = 0.5;
	data.ThrottleCurve2[3] = 0.75;
	data.ThrottleCurve2[4] = 1;
	data.Mixer0Type = 0;
	data.Mixer0Vector[0] = 0;
	data.Mixer0Vector[1] = 0;
	data.Mixer0Vector[2] = 0;
	data.Mixer0Vector[3] = 0;
	data.Mixer0Vector[4] = 0;
	data.Mixer1Type = 0;
	data.Mixer1Vector[0] = 0;
	data.Mixer1Vector[1] = 0;
	data.Mixer1Vector[2] = 0;
	data.Mixer1Vector[3] = 0;
	data.Mixer1Vector[4] = 0;
	data.Mixer2Type = 0;
	data.Mixer2Vector[0] = 0;
	data.Mixer2Vector[1] = 0;
	data.Mixer2Vector[2] = 0;
	data.Mixer2Vector[3] = 0;
	data.Mixer2Vector[4] = 0;
	data.Mixer3Type = 0;
	data.Mixer3Vector[0] = 0;
	data.Mixer3Vector[1] = 0;
	data.Mixer3Vector[2] = 0;
	data.Mixer3Vector[3] = 0;
	data.Mixer3Vector[4] = 0;
	data.Mixer4Type = 0;
	data.Mixer4Vector[0] = 0;
	data.Mixer4Vector[1] = 0;
	data.Mixer4Vector[2] = 0;
	data.Mixer4Vector[3] = 0;
	data.Mixer4Vector[4] = 0;
	data.Mixer5Type = 0;
	data.Mixer5Vector[0] = 0;
	data.Mixer5Vector[1] = 0;
	data.Mixer5Vector[2] = 0;
	data.Mixer5Vector[3] = 0;
	data.Mixer5Vector[4] = 0;
	data.Mixer6Type = 0;
	data.Mixer6Vector[0] = 0;
	data.Mixer6Vector[1] = 0;
	data.Mixer6Vector[2] = 0;
	data.Mixer6Vector[3] = 0;
	data.Mixer6Vector[4] = 0;
	data.Mixer7Type = 0;
	data.Mixer7Vector[0] = 0;
	data.Mixer7Vector[1] = 0;
	data.Mixer7Vector[2] = 0;
	data.Mixer7Vector[3] = 0;
	data.Mixer7Vector[4] = 0;

	UAVObjSetInstanceData(obj, instId, &data);

	// Initialize object metadata to their default values
	metadata.access = ACCESS_READWRITE;
	metadata.gcsAccess = ACCESS_READWRITE;
	metadata.telemetryAcked = 1;
	metadata.telemetryUpdateMode = UPDATEMODE_ONCHANGE;
	metadata.telemetryUpdatePeriod = 0;
	metadata.gcsTelemetryAcked = 1;
	metadata.gcsTelemetryUpdateMode = UPDATEMODE_ONCHANGE;
	metadata.gcsTelemetryUpdatePeriod = 0;
	metadata.loggingUpdateMode = UPDATEMODE_NEVER;
	metadata.loggingUpdatePeriod = 0;
	UAVObjSetMetadata(obj, &metadata);
}

/**
 * Get object handle
 */
UAVObjHandle MixerSettingsHandle()
{
	return handle;
}

/**
 * @}
 */

